<?php

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}


/**
 * Class Elementor_ShowWwehn_Control
 */
class Elementor_ShowWhen_Control {


	private static $instance = null;

	/**
	 * @return Elementor_ShowWhen_Control|null
	 */
	public static function get_instance() {
		if ( ! self::$instance ) {
			self::$instance = new self;
		}

		return self::$instance;
	}

	public function init() {
		if ( ! defined( 'ELEMENTOR_PATH' ) ) {
			return;
		}

		// Add section for settings
		add_action( 'elementor/element/common/_section_style/after_section_end', [ $this, 'register_section' ] );
		add_action( 'elementor/element/section/section_advanced/after_section_end', [ $this, 'register_section' ] );

		add_action( 'elementor/element/common/ecl_showwhen_section/before_section_end', [ $this, 'register_controls' ], 10, 2 );
		add_action( 'elementor/element/section/ecl_showwhen_section/before_section_end', [ $this, 'register_controls' ], 10, 2 );

		add_filter( 'elementor/widget/render_content', [ $this, 'content_change' ], 999, 2 );
		add_filter( 'elementor/section/render_content', [ $this, 'content_change' ], 999, 2 );

		add_filter( 'elementor/frontend/section/should_render', [ $this, 'section_should_render' ], 10, 2 );
		add_filter( 'elementor/frontend/widget/should_render', [ $this, 'section_should_render' ], 10, 2 );
		add_filter( 'elementor/frontend/repeater/should_render', [ $this, 'section_should_render' ], 10, 2 );

	}

	public function register_section( $element ) {
		$element->start_controls_section(
			'ecl_showwhen_section',
			[
				'tab'   => Controls_Manager::TAB_ADVANCED,
				'label' => __( 'Show When', 'visibility-showwhen-elementor' ),
			]
		);
		$element->end_controls_section();
	}

	/**
	 * @param $element \Elementor\Widget_Base
	 * @param $section_id
	 * @param $args
	 */
	public function register_controls( $element, $args ) {

		$element->add_control(
			'ecl_enabled', [
				'label'        => __( 'Enable Conditions', 'visibility-showwhen-elementor' ),
				'type'         => Controls_Manager::SWITCHER,
				'default'      => '',
				'label_on'     => __( 'Yes', 'visibility-showwhen-elementor' ),
				'label_off'    => __( 'No', 'visibility-showwhen-elementor' ),
				'return_value' => 'yes',
			]
		);

		$element->add_control(
			'ecl_show_start',
			[
				'type'        => Controls_Manager::DATE_TIME,
				'label'       => __( 'Show start:', 'visibility-showwhen-elementor' ),
				'default'     => [],
				'label_block' => true,
				'condition'   => [
					'ecl_enabled'     => 'yes',
				],
			]
		);

		$element->add_control(
			'ecl_show_end',
			[
				'type'        => Controls_Manager::DATE_TIME,
				'label'       => __( 'Show end:', 'visibility-showwhen-elementor' ),
				'default'     => [],
				'label_block' => true,
				'condition'   => [
					'ecl_enabled'      => 'yes',
				],
			]
		);
		
		$element->add_control(
			'ecl_show_tz',
			[
				'type'        => Controls_Manager::SELECT,
				'label'       => __( 'Timezone:', 'visibility-showwhen-elementor' ),
				'default'     => [],
				'options'	  => $this->get_timezones(),
				'label_block' => true,
				'condition'   => [
					'ecl_enabled'      => 'yes',
				],
			]
		);

	}
	
	private function get_timezones() {
		$timezone_identifiers = timezone_identifiers_list();
		$timezones = array();
		foreach ($timezone_identifiers as $key => $value) {
			array_push($timezones,$value);
		}
		return $timezones;
	}
	
	private function get_tz($tz) {
		$timezone_identifiers = timezone_identifiers_list();
		return timezone_open($timezone_identifiers[$tz]);  
	}

	/**
	 * @param string $content
	 * @param $widget \Elementor\Widget_Base
	 *
	 * @return string
	 */
	public function content_change( $content, $widget ) {

		if ( Plugin::$instance->editor->is_edit_mode() ) {
			return $content;
		}

		// Get the settings
		$settings = $widget->get_settings();

		if ( ! $this->should_render( $settings ) ) {
			return '';
		}

		return $content;

	}

	public function section_should_render( $should_render, $section ) {
		// Get the settings
		$settings = $section->get_settings();

		if ( ! $this->should_render( $settings ) ) {
			return false;
		}

		return $should_render;

	}

	private function should_render( $settings ) {
		$user_state = is_user_logged_in();

		if ( $settings['ecl_enabled'] == 'yes' ) {

			$start = date_create($settings['ecl_show_start'],  $this->get_tz($settings['ecl_show_tz']));
			$end = date_create($settings['ecl_show_end'], $this->get_tz($settings['ecl_show_tz']));
			

			if (time() > date_timestamp_get($start) && time() < date_timestamp_get($end)) {
				return true;
			} else {
				return false;
			}
		} else {
			return true;
		}
	}


}

Elementor_ShowWhen_Control::get_instance()->init();
